aboutsummaryrefslogtreecommitdiff
path: root/libXt/include/X11/IntrinsicP.h
diff options
context:
space:
mode:
Diffstat (limited to 'libXt/include/X11/IntrinsicP.h')
-rw-r--r--libXt/include/X11/IntrinsicP.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libXt/include/X11/IntrinsicP.h b/libXt/include/X11/IntrinsicP.h
index bb6570bbf..d3007ee07 100644
--- a/libXt/include/X11/IntrinsicP.h
+++ b/libXt/include/X11/IntrinsicP.h
@@ -52,16 +52,16 @@ SOFTWARE.
/*
* Field sizes and offsets of XrmResource must match those of XtResource.
* Type long is used instead of XrmQuark here because XrmQuark and String
* are not the same size on all systems.
*/
typedef struct {
- long xrm_name; /* Resource name quark */
- long xrm_class; /* Resource class quark */
- long xrm_type; /* Resource representation type quark */
+ intptr_t xrm_name; /* Resource name quark */
+ intptr_t xrm_class; /* Resource class quark */
+ intptr_t xrm_type; /* Resource representation type quark */
Cardinal xrm_size; /* Size in bytes of representation */
int xrm_offset; /* -offset-1 */
- long xrm_default_type; /* Default representation type quark */
+ intptr_t xrm_default_type; /* Default representation type quark */
XtPointer xrm_default_addr; /* Default resource address */
} XrmResource, *XrmResourceList;
@@ -52,16 +52,16 @@ SOFTWARE.
/*
* Field sizes and offsets of XrmResource must match those of XtResource.
- * Type long is used instead of XrmQuark here because XrmQuark and String
+ * Type intptr_t is used instead of XrmQuark here because XrmQuark and String
* are not the same size on all systems.
*/